summaryrefslogtreecommitdiffstats
path: root/khtml/ecma
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /khtml/ecma
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'khtml/ecma')
-rw-r--r--khtml/ecma/kjs_debugwin.cpp4
-rw-r--r--khtml/ecma/kjs_navigator.cpp2
-rw-r--r--khtml/ecma/xmlhttprequest.cpp42
-rw-r--r--khtml/ecma/xmlhttprequest.h16
4 files changed, 32 insertions, 32 deletions
diff --git a/khtml/ecma/kjs_debugwin.cpp b/khtml/ecma/kjs_debugwin.cpp
index 674a3f3c6..73a55cf94 100644
--- a/khtml/ecma/kjs_debugwin.cpp
+++ b/khtml/ecma/kjs_debugwin.cpp
@@ -860,8 +860,8 @@ bool KJSDebugWin::exception(ExecState *exec, const Value &value, bool inTryCatch
}
if (dontShowAgain) {
- KConfig *config = kapp->config();
- KConfigGroupSaver saver(config,TQString::fromLatin1("Java/JavaScript Settings"));
+ TDEConfig *config = kapp->config();
+ TDEConfigGroupSaver saver(config,TQString::fromLatin1("Java/JavaScript Settings"));
config->writeEntry("ReportJavaScriptErrors",TQVariant(false,0));
config->sync();
TQByteArray data;
diff --git a/khtml/ecma/kjs_navigator.cpp b/khtml/ecma/kjs_navigator.cpp
index 426c68343..9bd99ada7 100644
--- a/khtml/ecma/kjs_navigator.cpp
+++ b/khtml/ecma/kjs_navigator.cpp
@@ -306,7 +306,7 @@ PluginBase::PluginBase(ExecState *exec, bool loadPluginInfo)
continue;
}
// read configuration
- KConfig kc( locate ("data", pluginsinfo.toString()) );
+ TDEConfig kc( locate ("data", pluginsinfo.toString()) );
unsigned num = (unsigned int) kc.readNumEntry("number");
for ( unsigned n = 0; n < num; n++ ) {
kc.setGroup( TQString::number(n) );
diff --git a/khtml/ecma/xmlhttprequest.h b/khtml/ecma/xmlhttprequest.h
index 2c646708e..93420453e 100644
--- a/khtml/ecma/xmlhttprequest.h
+++ b/khtml/ecma/xmlhttprequest.h
@@ -75,12 +75,12 @@ namespace KJS {
XMLHttpRequestQObject *qObject;
#ifdef APPLE_CHANGES
- void slotData( KIO::Job* job, const char *data, int size );
+ void slotData( TDEIO::Job* job, const char *data, int size );
#else
- void slotData( KIO::Job* job, const TQByteArray &data );
+ void slotData( TDEIO::Job* job, const TQByteArray &data );
#endif
- void slotFinished( KIO::Job* );
- void slotRedirection( KIO::Job*, const KURL& );
+ void slotFinished( TDEIO::Job* );
+ void slotRedirection( TDEIO::Job*, const KURL& );
void processSyncLoadResults(const TQByteArray &data, const KURL &finalURL, const TQString &headers);
@@ -103,7 +103,7 @@ namespace KJS {
TQString m_mimeTypeOverride;
TQString contentType;
- KIO::TransferJob * job;
+ TDEIO::TransferJob * job;
XMLHttpRequestState state;
JSEventListener *onReadyStateChangeListener;
@@ -129,9 +129,9 @@ namespace KJS {
XMLHttpRequestQObject(XMLHttpRequest *_jsObject);
public slots:
- void slotData( KIO::Job* job, const TQByteArray &data );
- void slotFinished( KIO::Job* job );
- void slotRedirection( KIO::Job* job, const KURL& url);
+ void slotData( TDEIO::Job* job, const TQByteArray &data );
+ void slotFinished( TDEIO::Job* job );
+ void slotRedirection( TDEIO::Job* job, const KURL& url);
private:
XMLHttpRequest *jsObject;
diff --git a/khtml/ecma/xmlhttprequest.cpp b/khtml/ecma/xmlhttprequest.cpp
index 08ba07519..8a8a86c16 100644
--- a/khtml/ecma/xmlhttprequest.cpp
+++ b/khtml/ecma/xmlhttprequest.cpp
@@ -42,7 +42,7 @@
#include "KWQLoader.h"
#else
#include <kio/netaccess.h>
-using KIO::NetAccess;
+using TDEIO::NetAccess;
#endif
#define BANNED_HTTP_HEADERS "authorization,proxy-authorization,"\
@@ -81,23 +81,23 @@ XMLHttpRequestQObject::XMLHttpRequestQObject(XMLHttpRequest *_jsObject)
}
#ifdef APPLE_CHANGES
-void XMLHttpRequestQObject::slotData( KIO::Job* job, const char *data, int size )
+void XMLHttpRequestQObject::slotData( TDEIO::Job* job, const char *data, int size )
{
jsObject->slotData(job, data, size);
}
#else
-void XMLHttpRequestQObject::slotData( KIO::Job* job, const TQByteArray &data )
+void XMLHttpRequestQObject::slotData( TDEIO::Job* job, const TQByteArray &data )
{
jsObject->slotData(job, data);
}
#endif
-void XMLHttpRequestQObject::slotFinished( KIO::Job* job )
+void XMLHttpRequestQObject::slotFinished( TDEIO::Job* job )
{
jsObject->slotFinished(job);
}
-void XMLHttpRequestQObject::slotRedirection( KIO::Job* job, const KURL& url)
+void XMLHttpRequestQObject::slotRedirection( TDEIO::Job* job, const KURL& url)
{
jsObject->slotRedirection( job, url );
}
@@ -344,7 +344,7 @@ void XMLHttpRequest::send(const TQString& _body)
const TQString protocol = url.protocol().lower();
// Abandon the request when the protocol is other than "http",
// instead of blindly doing a KIO::get on other protocols like file:/.
if (!protocol.startsWith("http") && !protocol.startsWith("webdav"))
{
abort();
@@ -359,14 +359,14 @@ void XMLHttpRequest::send(const TQString& _body)
TQCString str = _body.utf8();
buf.duplicate(str.data(), str.size() - 1);
- job = KIO::http_post( url, buf, false );
+ job = TDEIO::http_post( url, buf, false );
if(contentType.isNull())
job->addMetaData( "content-type", "Content-type: text/plain" );
else
job->addMetaData( "content-type", contentType );
}
else {
- job = KIO::get( url, false, false );
+ job = TDEIO::get( url, false, false );
}
if (!requestHeaders.isEmpty()) {
@@ -421,22 +421,22 @@ void XMLHttpRequest::send(const TQString& _body)
return;
}
- qObject->connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
- TQT_SLOT( slotFinished( KIO::Job* ) ) );
+ qObject->connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
+ TQT_SLOT( slotFinished( TDEIO::Job* ) ) );
#ifdef APPLE_CHANGES
- qObject->connect( job, TQT_SIGNAL( data( KIO::Job*, const char*, int ) ),
- TQT_SLOT( slotData( KIO::Job*, const char*, int ) ) );
+ qObject->connect( job, TQT_SIGNAL( data( TDEIO::Job*, const char*, int ) ),
+ TQT_SLOT( slotData( TDEIO::Job*, const char*, int ) ) );
#else
- qObject->connect( job, TQT_SIGNAL( data( KIO::Job*, const TQByteArray& ) ),
- TQT_SLOT( slotData( KIO::Job*, const TQByteArray& ) ) );
+ qObject->connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ),
+ TQT_SLOT( slotData( TDEIO::Job*, const TQByteArray& ) ) );
#endif
- qObject->connect( job, TQT_SIGNAL(redirection(KIO::Job*, const KURL& ) ),
- TQT_SLOT( slotRedirection(KIO::Job*, const KURL&) ) );
+ qObject->connect( job, TQT_SIGNAL(redirection(TDEIO::Job*, const KURL& ) ),
+ TQT_SLOT( slotRedirection(TDEIO::Job*, const KURL&) ) );
#ifdef APPLE_CHANGES
KWQServeRequest(khtml::Cache::loader(), doc->docLoader(), job);
#else
- KIO::Scheduler::scheduleJob( job );
+ TDEIO::Scheduler::scheduleJob( job );
#endif
}
@@ -610,7 +610,7 @@ void XMLHttpRequest::processSyncLoadResults(const TQByteArray &data, const KURL
slotFinished(0);
}
-void XMLHttpRequest::slotFinished(KIO::Job *)
+void XMLHttpRequest::slotFinished(TDEIO::Job *)
{
if (decoder) {
response += decoder->flush();
@@ -625,7 +625,7 @@ void XMLHttpRequest::slotFinished(KIO::Job *)
decoder = 0;
}
-void XMLHttpRequest::slotRedirection(KIO::Job*, const KURL& url)
+void XMLHttpRequest::slotRedirection(TDEIO::Job*, const KURL& url)
{
if (!urlMatchesDocumentDomain(url)) {
abort();
@@ -633,9 +633,9 @@ void XMLHttpRequest::slotRedirection(KIO::Job*, const KURL& url)
}
#ifdef APPLE_CHANGES
-void XMLHttpRequest::slotData( KIO::Job*, const char *data, int len )
+void XMLHttpRequest::slotData( TDEIO::Job*, const char *data, int len )
#else
-void XMLHttpRequest::slotData(KIO::Job*, const TQByteArray &_data)
+void XMLHttpRequest::slotData(TDEIO::Job*, const TQByteArray &_data)
#endif
{
if (state < Loaded ) {
@@ -344,7 +344,7 @@ void XMLHttpRequest::send(const TQString& _body)
const TQString protocol = url.protocol().lower();
// Abandon the request when the protocol is other than "http",
- // instead of blindly doing a KIO::get on other protocols like file:/.
+ // instead of blindly doing a TDEIO::get on other protocols like file:/.
if (!protocol.startsWith("http") && !protocol.startsWith("webdav"))
{